<?php

class Face2FaceAdmin {

    private $options;

    public function __construct() {
        global $wpdb;
        $this->_wpdb = $wpdb;
        $this->init();
        $this->options = get_option( 'face_2_face_data' );
    }

    public function init(){
        add_action( 'admin_menu', array($this,'face2FaceMenu') );
        add_action( 'admin_init', array($this ,'face2FaceSettings' ));
        add_filter( 'wp_dropdown_pages', array($this ,'face2FaceMultiPage' ),10,3 );
        add_action( 'admin_enqueue_scripts', array($this,'face2FaceEnqueueScripts') );
    }

    public function face2FaceMenu(){
        add_menu_page(
            __( 'Face2Face', 'go_live' ),
            'Face2Face',
            'manage_options',
            'face-2-face-admin',
            array($this ,'face2FaceAdminPage'),
            FACE2FACE_PLUGIN_URL.'/assets/images/icon.png',
            6
        );
    }

    public function face2FaceAdminPage(){ ?>
        <div class="wrap">
            <form method="post" action="options.php">
            <?php
                // This prints out all hidden setting fields
                settings_fields( 'face_2_face_settings' );
                do_settings_sections( 'face-2-face-admin' );
                submit_button();
            ?>
            </form>
            <table class="form-table">
                <tr>
                    <th scope="row">Shortcode</th>
                    <td>
                    <input type="text" readonly value="[live_streaming]" onClick="this.select();">
                    </td>
                </tr>
            </table>
        </div>
      <?php  
    }

    function face2FaceSettings(){
        
        register_setting(
            'face_2_face_settings', 
            'face_2_face_data' 
        );

        add_settings_section(
            'face_2_face_section', 
            'Face2Face Settings', 
            array( $this, 'tokboxSectionCallback' ),
            'face-2-face-admin'
        );  

        add_settings_field(
            'api_key',
            'API KEY', 
            array( $this, 'apiKeyCallback' ),
            'face-2-face-admin', 
            'face_2_face_section'          
        );      

        add_settings_field(
            'secret_key', 
            'Secret Key', 
            array( $this, 'secretKeyCallback' ), 
            'face-2-face-admin', 
            'face_2_face_section'
        );

        add_settings_section(
            'face_2_face_option_section', 
            '', 
            array( $this, 'adminSectionCallback' ),
            'face-2-face-admin'
        );  

        add_settings_field(
            'face_2_face_admin',
            'Choose Operator', 
            array( $this, 'face2FaceAdminCallback' ),
            'face-2-face-admin', 
            'face_2_face_option_section'          
        ); 
        add_settings_field(
            'face_2_face_include_pages',
            'Include on pages', 
            array( $this, 'face2FaceIncludePageCallback' ),
            'face-2-face-admin', 
            'face_2_face_option_section'          
        ); 
        add_settings_field(
            'face_2_face_all_pages',
            'Show on all pages', 
            array( $this, 'face2FaceAllPageCallback' ),
            'face-2-face-admin', 
            'face_2_face_option_section'          
        ); 
        add_settings_field(
            'face_2_face_exclude_pages',
            'Exclude on pages', 
            array( $this, 'face2FaceExcludePageCallback' ),
            'face-2-face-admin', 
            'face_2_face_option_section'          
        ); 
        
    }

    public function face2FaceEnqueueScripts($hook)
    {
        if ( 'toplevel_page_face-2-face-admin' != $hook ) {
            return;
        }
        wp_enqueue_style( 'face2face_admin_s2select_styles', 'https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.13/css/select2.min.css');
        wp_enqueue_script( 'face2face_admin_s2select_script', 'https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.13/js/select2.min.js', array(), '1.0' );
        wp_enqueue_script( 'face2face_admin_script', plugin_dir_url( __FILE__ ) . 'js/Face2FaceAdmin.js', array(), '1.0' );
        
    }

    public function adminSectionCallback(){
        echo '<hr/><h4>Admin Setting</h4><hr/>';
    }

    public function tokboxSectionCallback(){
        echo '<hr/><h4>Vonage/Tokbox Setting</h4><hr/>';
    }

    public function apiKeyCallback(){
        printf(
            '<input type="text" id="api_key" name="face_2_face_data[api_key]" value="%s" />',
            isset( $this->options['api_key'] ) ? esc_attr( $this->options['api_key']) : ''
        );
    }

    public function secretKeyCallback(){
        printf(
            '<input type="text" id="secret_key" name="face_2_face_data[secret_key]" value="%s" />',
            isset( $this->options['secret_key'] ) ? esc_attr( $this->options['secret_key']) : ''
        );
    }

    public function face2FaceAdminCallback(){
        $selected = isset( $this->options['face_2_face_admin'] ) ? esc_attr( $this->options['face_2_face_admin']) : 0;
        $args = array('name'=>'face_2_face_data[face_2_face_admin]','id'=>'face_2_face_admin','role'=>'administrator','selected'=>$selected,'show_option_none'=>'Select User');
        wp_dropdown_users( $args);
        
    }

    public function face2FaceIncludePageCallback(){
        $selected = isset( $this->options['face_2_face_include_pages'] ) ? (array) $this->options['face_2_face_include_pages'] : array();
        $selected = array_map( 'esc_attr', $selected );
        $args = array('name'=>'face_2_face_data[face_2_face_include_pages][]','multiselect'=>'true','walker' => new Walker_PageDropdown_Multiple_Face2Face(),'id'=>'face_2_face_include_pages','selected'=>$selected,'show_option_none'=>'Select Pages to show Face2Face');
        wp_dropdown_pages( $args);
        printf(
            '<i>doesn\'t work when all page option is checked</i>'
        );
    }

    public function face2FaceAllPageCallback(){
        printf(
            '<input type="checkbox" id="face_2_face_all_pages" name="face_2_face_data[face_2_face_all_pages]" value="1" %s />',
            (isset( $this->options['face_2_face_all_pages']) && $this->options['face_2_face_all_pages']==1) ? esc_attr( 'checked="checked"') : ''
        );
    }

    public function face2FaceExcludePageCallback(){
        $selected = isset( $this->options['face_2_face_exclude_pages'] ) ? (array) $this->options['face_2_face_exclude_pages'] : array();
        $selected = array_map( 'esc_attr', $selected );
        $args = array('name'=>'face_2_face_data[face_2_face_exclude_pages][]','multiselect'=>'true','walker' => new Walker_PageDropdown_Multiple_Face2Face(),'id'=>'face_2_face_exclude_pages','selected'=>$selected,'show_option_none'=>'Select Pages to show Face2Face');
        wp_dropdown_pages( $args);
        printf(
            '<i>only work with all page option</i>'
        );
    }

    public function face2FaceMultiPage($output, $parsed_args, $pages){
        if(!empty($parsed_args['multiselect'])){
            $output =  str_replace( '<select ', '<select multiple="multiple" ', $output );
        }
        return $output;
    }
}
new Face2FaceAdmin;