<?php

/**
 * Fired during plugin activation
 *
 * @link       https://face2facewp.com/
 * @since      1.0.0
 *
 * @package    Face2FaceWp
 * @subpackage Face2FaceWp/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Face2FaceWp
 * @subpackage Face2FaceWp/includes
 * @author     Phillip Dane <info@face2facewp.co>
 */
class Face2Face_Activator {

	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0.0
	 */
	public static function activate() {
        
        global $wpdb;
        $dbSessionTable = $wpdb->prefix.'face2face_tokbox_sessions';
		$dbCustomerTable = $wpdb->prefix.'face2face_customer_request';
		$dbGuestTable = $wpdb->prefix.'face2face_guest';
		
		$charset_collate = $wpdb->get_charset_collate();

		$dbSession = "CREATE TABLE IF NOT EXISTS $dbSessionTable (
			id int(11) NOT NULL AUTO_INCREMENT,
			operator_id int(11) DEFAULT NULL,
			session_id varchar(245) DEFAULT NULL,
			token text,
			status varchar(245) DEFAULT NULL,
			start_date_time datetime DEFAULT NULL,
			end_date_time datetime DEFAULT NULL,
			created_at timestamp NULL DEFAULT '0000-00-00 00:00:00' ON UPDATE CURRENT_TIMESTAMP,
			PRIMARY KEY  (id)
		) $charset_collate;";

		$dbCustomer = "CREATE TABLE IF NOT EXISTS $dbCustomerTable (
			id mediumint(9) NOT NULL AUTO_INCREMENT,
			user_id varchar(20) NOT NULL,
			operator_id mediumint(9) NOT NULL,
			request_status varchar(20) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT 'pending',
			created_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
			updated_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
			PRIMARY KEY  (id)
		  ) $charset_collate;";

		$dbGuest = "CREATE TABLE IF NOT EXISTS $dbGuestTable (
			id mediumint(9) NOT NULL AUTO_INCREMENT,
			full_name varchar(120) COLLATE utf8mb4_unicode_ci NOT NULL,
			email varchar(50) COLLATE utf8mb4_unicode_ci NOT NULL,
			phone varchar(20) COLLATE utf8mb4_unicode_ci NOT NULL,
			created_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
			PRIMARY KEY  (id)
		) $charset_collate;";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );	
		dbDelta( $dbSession );
		dbDelta( $dbCustomer );
		dbDelta( $dbGuest );
        
        //flush_rewrite_rules();

	}

}
