<?php

class Face2Face {

    public $dbSessionTable,$dbCustomerTable;

    public function __construct() {
        
        global $wpdb;
        $this->_wpdb = $wpdb;
        $this->dbSessionTable = $this->_wpdb->prefix.'face2face_tokbox_sessions';
        $this->dbCustomerTable = $this->_wpdb->prefix.'face2face_customer_request';
        $this->dbGuestTable = $this->_wpdb->prefix.'face2face_guest';
        $this->options = get_option( 'face_2_face_data' );
        $this->init();
        
        require_once( FACE2FACE_PLUGIN_DIR . "vendor/autoload.php");
        require_once( FACE2FACE_PLUGIN_DIR. "includes/face2FaceTokBox.php");
        require_once( FACE2FACE_PLUGIN_DIR. "admin/face2FaceAdmin.php");
        require_once( FACE2FACE_PLUGIN_DIR. "admin/Walker_PageDropdown_Multiple_Face2Face.php");
        require_once( FACE2FACE_PLUGIN_DIR. "public/face2FacePublic.php");
    }

    public function init(){
        add_filter( 'kses_allowed_protocols', array($this ,'face2faceAllowedProtocols' ),100,1);
        add_action( 'wp_ajax_face2face_request', array( $this, 'face2face_request' ) );
		add_action( 'wp_ajax_face2face_customer_status', array( $this, 'face2face_customer_status' ) );
		add_action( 'wp_ajax_face2face_leave_customer', array( $this, 'face2face_leave_customer' ) );
        add_action( 'wp_ajax_face2face_check_vendor', array( $this, 'face2face_check_vendor' ) );
        
        add_action( 'wp_ajax_nopriv_face2face_request', array( $this, 'face2face_request' ) );
        add_action( 'wp_ajax_nopriv_face2face_customer_status', array( $this, 'face2face_customer_status' ) );
		add_action( 'wp_ajax_nopriv_face2face_leave_customer', array( $this, 'face2face_leave_customer' ) );
        add_action( 'wp_ajax_nopriv_face2face_check_vendor', array( $this, 'face2face_check_vendor' ) );

    }

    public function face2faceAllowedProtocols($protocols){
        $protocols[] = 'ionic';
        return $protocols;
    }

    private function get_operator_id($request){
        $operator_id = false;
        if(!empty($this->options['face_2_face_admin'])):
            $operator_id = $this->options['face_2_face_admin'];
        endif;
        return apply_filters('f2f_set_operator_id',$operator_id,$request);
    }

    function face2face_request() {
        if ( ! wp_verify_nonce( $_POST['f2fn'], 'f2f-nonce' ) ) {
            die ( 'Busted!');
        }
        $response = array('status'=>false,'message'=>'Something went wrong Please try again.');
        $operator_id = $this->get_operator_id($_POST);
        if($operator_id):
            if(is_user_logged_in()):
                $current_user = wp_get_current_user();
                $user_id = $current_user->ID;
                $userName = $current_user->display_name;
                
                if($operator_id == $user_id):
                    $response = array('status'=>false,'message'=>'cannot go live with your own Account.');
                endif;
            else:
                if(sanitize_email($_POST['email']) && sanitize_text_field($_POST['full_name']) && sanitize_text_field($_POST['phone'])){
                    
                    $data['email'] = sanitize_email($_POST['email']);
                    $data['full_name'] = sanitize_text_field($_POST['full_name']);
                    $data['phone'] = sanitize_text_field($_POST['phone']);
                    $userName = $data['full_name'];
                    $format = array('%s','%s','%d');
                    $check_email = $this->_wpdb->get_var("SELECT id FROM $this->dbGuestTable WHERE email = '{$data['email']}' LIMIT 1");
                    if($check_email){
                        $guest_id = $check_email;
                    } else {
                        $this->_wpdb->insert($this->dbGuestTable,$data,$format);
                        $guest_id = $this->_wpdb->insert_id;
                    }
                    $user_id = 'wp'.$guest_id.'f2fn';
                    setcookie('_f2f_user', $user_id, time() + (86400 * 30), "/");
                } else{
                    $response = array('status'=>false,'message'=>'Invalid Data.');
                }

            endif;
            
            if(!empty($user_id)){
                $fetch_user_request = $this->_wpdb->get_row("SELECT id,request_status FROM $this->dbCustomerTable WHERE user_id = '{$user_id}' and operator_id = $operator_id", ARRAY_A);
                $where = array('user_id' => $user_id,'operator_id' => $operator_id);
                $data = array('user_id' => $user_id,'operator_id' => $operator_id,'request_status'=>'pending');
                $format = array('%s','%d','%s');
                $send_notification = false;
                if(!empty($fetch_user_request)):
                    if(in_array($fetch_user_request['request_status'],array('completed','declined','missed'))):
                        $send_notification = true;
                        
                        $result = $this->_wpdb->update($this->dbCustomerTable, $data, $where,$format);
                        
                    endif;
                    if($fetch_user_request['request_status']=='pending'):
                        $send_notification = false;
                        $response = array('status'=>true,'data'=>array('sessionId'=>'','tokboxToken'=>''),'message'=>'Waiting for vendor to respond your request.');
                    endif;
                    if($fetch_user_request['request_status']=='started'):
                        $send_notification = false;
                        $sessionId = get_user_meta( $operator_id, 'tokboxsessionid',true );
                        $tokboxToken = get_user_meta( $operator_id, 'tokboxtoken',true );
                        $response = array('status'=>true,'data'=>array('sessionId'=>$sessionId,'tokboxToken'=>$tokboxToken),'message'=>'');
                    endif;
                else:
                    $send_notification = true;
                    $result = $this->_wpdb->insert($this->dbCustomerTable, $data,$format);
                    
                endif;
                
                if($send_notification){
                    $this->push_notification($operator_id,$user_id,$userName);
                    $response = array('status'=>true,'data'=>array('sessionId'=>'','tokboxToken'=>''),'message'=>'Waiting for Operator to respond your request.');
                }else {
                    $response = array('status'=>true,'message'=>'Waiting for Operator to respond your request.');
                }
            }
        endif;
        
		
		wp_send_json($response);
		wp_die();
    }

    function push_notification($operator_id,$user_id,$userName){

        $content = array(
            "en" => $userName.' has sent you a Face2Face request. !',
        );
        $headings = array("en" => $userName);
        $hashes_array = array();
        array_push($hashes_array, array(
            "id" => "answer",
            "text" => "Answer"
        ), array( 
            "id" => "decline",
            "text" => "Decline"
        ));

        $fields = array(
            'app_id' => "6167e2f8-64db-42c2-9399-687a592ef985",
            'include_external_user_ids' => array($operator_id),
            'android_sound' => 'notification',
            'android_group' => 'Face2Face',
            'android_channel_id' => '69f52c8a-62fa-4073-9e29-b7f592e3e151',
            'headings' =>$headings,
            'contents' => $content,
            'buttons' => $hashes_array,
            'data' => array("user_id" => $user_id),
            'ios_sound' => "notification.wav"
        );
  
        $fields = json_encode($fields);
  
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, "https://onesignal.com/api/v1/notifications");
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json; charset=utf-8',
            'Authorization: Basic Y2EyMDMwYTAtNWNiZC00MDE2LThiOTctOWRjOWQyNGNlM2Ew'
        ));
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
        curl_setopt($ch, CURLOPT_HEADER, FALSE);
        curl_setopt($ch, CURLOPT_POST, TRUE);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $fields);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
        $response = curl_exec($ch);
        curl_close($ch);
        return $response;
    }

    function face2face_customer_status() {
        if ( ! wp_verify_nonce( $_POST['f2fn'], 'f2f-nonce' ) ) {
            die ( 'Busted!');
        }
        $error = false;
        $response = array('status'=>false);
        $operator_id = $this->get_operator_id($_POST);
        if($operator_id):
            if(is_user_logged_in()):
                $current_user = wp_get_current_user();
                $user_id = $current_user->ID;
                
                if($operator_id == $user_id):
                    $error = true;
                    $response = array('status'=>false,'message'=>'Operator cannot call!');
                endif;
            else:
                
                if(isset($_COOKIE['_f2f_user'])):
                    $user_id = $_COOKIE['_f2f_user'];
                endif;
            endif;
        else:
            $error = true;
            $response = array('status'=>false,'message'=>'Operator not Active!');
        endif;
        
        if(!$error):
            $fetch_user_request = $this->_wpdb->get_row("SELECT id,request_status FROM $this->dbCustomerTable WHERE user_id = '{$user_id}' and operator_id = $operator_id", ARRAY_A);
            if(!empty($fetch_user_request)):
                if($fetch_user_request['request_status']=='pending'):
                    $response = array('status'=>true,'data'=>array('sessionId'=>'','tokboxToken'=>''),'message'=>'Waiting for vendor to respond your request.');
                endif;
                if($fetch_user_request['request_status']=='started'):
                    $sessionId = get_user_meta( $operator_id, 'tokboxsessionid',true );
                    $tokboxToken = get_user_meta( $operator_id, 'tokboxtoken',true );
                    $response = array('status'=>true,'data'=>array('sessionId'=>$sessionId,'tokboxToken'=>$tokboxToken),'message'=>'');
                endif;
            endif;
        endif;
		
		wp_send_json($response);
		wp_die();
    }
    
    function face2face_leave_customer() {
        if ( ! wp_verify_nonce( $_POST['f2fn'], 'f2f-nonce' ) ) {
            die ( 'Busted!');
        }
        $response = array('status'=>false);
        $operator_id = $this->get_operator_id($_POST);
        if($operator_id):
            if(is_user_logged_in()):
                $current_user = wp_get_current_user();
                $user_id = $current_user->ID;
            else:
                if(isset($_COOKIE['_f2f_user'])):
                    $user_id = $_COOKIE['_f2f_user'];
                endif;
            endif;
            if(!empty($user_id)):
                $fetch_user_request = $this->_wpdb->get_row("SELECT id,request_status FROM $this->dbCustomerTable WHERE user_id = $user_id and operator_id = $operator_id", ARRAY_A);
                $where = array('user_id' => $user_id,'operator_id' => $operator_id);
                if($fetch_user_request['request_status']=='started'):
                    $sessionId = get_user_meta( $operator_id, 'tokboxsessionid',true );
                    $data = array("status"=>"disconnected","end_date_time" => date('Y-m-d H:i:s'));
                    $this->_wpdb->update($this->dbSessionTable, $data, array('session_id'=> $sessionId));
                    $data = array("request_status"=>"completed");
                    $response = array('status'=>true);
                else:
                    $data = array('request_status'=>'missed');
                    $response = array('status'=>true);
                endif;
                $result = $this->_wpdb->update($this->dbCustomerTable, $data, $where);
            endif;
        endif;
        wp_send_json($response);
		wp_die();
    }
    
    function face2face_check_vendor(){
        if ( ! wp_verify_nonce( $_POST['f2fn'], 'f2f-nonce' ) ) {
            die ( 'Busted!');
        }
        $response = array('status'=>false,'message'=>'invaild Request');
        $operator_id = $this->get_operator_id($_POST);
        if($operator_id):
            if(is_user_logged_in()):
                $current_user = wp_get_current_user();
                $user_id = $current_user->ID;
                
            else:
                if(isset($_COOKIE['_f2f_user'])):
                    $user_id = $_COOKIE['_f2f_user'];
                endif;
            endif;
            if(!empty($user_id)):
                
               // echo "SELECT id,request_status FROM $this->dbCustomerTable WHERE user_id = '{$user_id}' and operator_id = $operator_id";
                $checkDB = $this->_wpdb->get_row("SELECT id,request_status FROM $this->dbCustomerTable WHERE user_id = '{$user_id}' and operator_id = $operator_id", ARRAY_A);
                if(!empty($checkDB) && $checkDB['request_status']=='started'):
                    $sessionId = get_user_meta( $operator_id, 'tokboxsessionid',true );
                    $tokboxToken = get_user_meta( $operator_id, 'tokboxtoken',true );
                    $response = array('status'=>'started','data'=>array('sessionId'=>$sessionId,'tokboxToken'=>$tokboxToken));
                elseif($checkDB['request_status']=='declined'):
                    $response = array('status'=>'declined','data'=>array('sessionId'=>'','tokboxToken'=>''),'message'=>'Operator has declined your request.Operator will get back to you.');
                else:
                    $response = array('status'=>'pending');
                endif;
            endif;
        else:

        endif;
        
        wp_send_json($response);
		wp_die();
    }
}