<?php
header("Access-Control-Allow-Origin: *");
use OpenTok\OpenTok;
use OpenTok\MediaMode;
use OpenTok\ArchiveMode;
use OpenTok\Role;
use OpenTok\Archive;
class Face2FaceTokBox {

    protected $apiKey,$apiSecret,$openTok,$sessionId,$tokToken;
    private $options;

    public function __construct() {
        global $wpdb;
        $this->_wpdb = $wpdb;
        $this->dbSessionTable = $this->_wpdb->prefix.'face2face_tokbox_sessions';
        $this->dbCustomerTable = $this->_wpdb->prefix.'face2face_customer_request';
        $this->dbGuestTable = $this->_wpdb->prefix.'face2face_guest';
        $this->openTok = '';
        $this->userId = '';
        $this->routesInit();
        $this->openTokInit();
       
    }

    public function routesInit(){
        
        add_action('rest_api_init', array($this,'registerCustomRestRoutes'));
    }

    public function openTokInit(){
        $this->options = get_option( 'face_2_face_data' );
        $this->apiKey = isset( $this->options['api_key'] ) ? esc_attr( $this->options['api_key']) : '';
        $this->apiSecret = isset( $this->options['secret_key'] ) ? esc_attr( $this->options['secret_key']) : '';
        $this->openTok = new OpenTok($this->apiKey,$this->apiSecret);
    }
    
    public function registerCustomRestRoutes(){
        
        register_rest_route('go-live', '/create-session-token/', array(
            'methods' => 'POST',
            'callback' => array($this,'openTokSessionCreate'),
            'permission_callback'=>function() { return ''; }
          ));

        register_rest_route('go-live', '/login/', array(
            'methods'  => 'POST',
            'callback' => array($this,'vendorLogin'),
            'permission_callback'=>function() { return ''; }
        ));

        register_rest_route('go-live', '/save-push-token/', array(
            'methods'  => 'POST',
            'callback' => array($this,'savePushToken'),
            'permission_callback'=>function() { return ''; }
        ));
        
        register_rest_route('go-live', '/session-disconnect/', array(
            'methods'  => 'POST',
            'callback' => array($this,'stopTokboxSession'),
            'permission_callback'=>function() { return ''; }
        ));

        register_rest_route('go-live', '/get-golive-requests/', array(
            'methods'  => 'POST',
            'callback' => array($this,'getGoLiveRequests'),
            'permission_callback'=>function() { return ''; }
        ));

        register_rest_route('go-live', '/set-request-status/', array(
            'methods'  => 'POST',
            'callback' => array($this,'setRequestStatus'),
            'permission_callback'=>function() { return ''; }
        ));

        register_rest_route('go-live', '/get-customer-info/', array(
            'methods'  => 'POST',
            'callback' => array($this,'getCustomerInfo'),
            'permission_callback'=>function() { return ''; }
        ));

        register_rest_route('go-live', '/send-message/', array(
            'methods'  => 'POST',
            'callback' => array($this,'sendMessage'),
            'permission_callback'=>function() { return ''; }
        ));
        register_rest_route('go-live', '/notification-settings/', array(
            'methods'  => 'POST',
            'callback' => array($this,'pushNotificationSetting'),
            'permission_callback'=>function() { return ''; }
        ));
        
      }

    public function getCustomerInfo($request){
        $customerId = $request['customer_id'];
        $user_info = get_userdata($customerId);
        $data['user_name'] = $user_info->first_name .' '.$user_info->last_name;
        $data['image'] = get_avatar_url( $customerId );
        return $data;
    }

    private function get_face_2_face_admin($request){
        if(empty($request['seller_id']) || $request['seller_id']!=$this->options['face_2_face_admin']){
            $this->userId = false;
        }else {
            $this->userId = $this->options['face_2_face_admin'];
        }
        return apply_filters('f2f_set_admin_id',$this->userId,$request);
    }

    public function openTokSessionCreate($request){

        $this->userId = $this->get_face_2_face_admin($request);

        if(!$this->userId){
            echo json_encode(array('status'=>false,'message'=>"Invalid Operator Request!"));exit;
        }
        try{
            $session = $this->openTok->createSession(array( 'mediaMode' => 'disabled' ));
            $this->sessionId = $session->getSessionId();
            update_user_meta( $this->userId, 'tokboxsessionid', $this->sessionId);

            // generate Token
            $this->tokToken = $this->openTok->generateToken($this->sessionId, array('expireTime' => time()+(7 * 24 * 60 * 60)));
            update_user_meta( $this->userId, 'tokboxtoken', $this->tokToken);
            update_user_meta( $this->userId, 'golivestatus', 'online');
            $this->storeTokboxSession();
            echo json_encode(array('tok_api_key'=>$this->apiKey, 'tok_session_id'=> $this->sessionId,'tok_token'=> $this->tokToken, 'status'=>true,'message'=>'Session Id and token generated!' ));
            exit;
        }catch(Exception $e){
            //echo $e->getMessage();
            echo json_encode(array('status'=>false,'message'=>'Could not create session Id and Token!'));
            exit;
        }

    }

    public function storeTokboxSession(){
        $data = array(
            "operator_id" => $this->userId,
            "session_id"=>$this->sessionId,
            "token"=>$this->tokToken,
            "status"=>"connected",
            "start_date_time" => date('Y-m-d H:i:s')
        );
        $this->_wpdb->insert($this->dbSessionTable, $data);
    }

    public function getGoLiveRequests($request){
        $operator_id = $this->get_face_2_face_admin($request);

        if(!$operator_id){
            echo json_encode(array('status'=>false,'message'=>"Invalid Operator Request!"));exit;
        }
        $userData = array();
        $status = $request['status'];
        $query ="SELECT user_id, updated_at, request_status from {$this->dbCustomerTable} where operator_id = $operator_id and request_status='$status'";

        $rows = $this->_wpdb->get_results($query, ARRAY_A);

        if(!empty($rows) && count($rows) > 0){
            foreach($rows as $key => $value){
                $user_info = get_userdata($value['user_id']);
                if(!empty($user_info)):
                    $data['user_name'] = $user_info->first_name .' '.$user_info->last_name;
                else:
                    $guest_info= str_replace('wp','',$value['user_id']);
                    $f2f_guest_id =  str_replace('f2fn','',$guest_info);
                    $data['user_name'] = $this->_wpdb->get_var("SELECT full_name FROM $this->dbGuestTable WHERE id = {$f2f_guest_id} LIMIT 1");
                endif;
                $data['user_id'] = $value['user_id'];
                $data['requested_at'] = $value['updated_at'];
                $data['status'] = $value['request_status'];
                $data['image'] = get_avatar_url( $value['user_id'] );
                $userData[] = $data;
            }
            echo json_encode(array('status'=>true,'requests'=>$userData));
            exit;
        }else{
            echo json_encode(array('status'=>false,'message'=>'No one here yet, but they are coming.','requests'=>array()));
        }
    }

    public function setRequestStatus($request){

        $operator_id = $this->get_face_2_face_admin($request);

        if(!$operator_id){
            echo json_encode(array('status'=>false,'message'=>"Invalid Operator Request!"));exit;
        }
        
        if(!empty($request['user_id']) && !empty($request['status'])){
            $data = array("request_status"=>$request['status']);
            $this->_wpdb->update( $this->dbCustomerTable, $data, array('user_id'=> $request['user_id'],'operator_id'=>$operator_id));
            if($request['status'] == 'started'){
                echo json_encode(array('status'=>true,'message'=>"Go Live session started!"));exit;
            }else{
                echo json_encode(array('status'=>true,'message'=>"Go Live Request Declined!"));exit;
            }
        }else{
            echo json_encode(array('status'=>false,'message'=>"SellerId or userId not present!"));exit;
        }
    }

    public function stopTokboxSession($request){

        $operator_id = $this->get_face_2_face_admin($request);

        if(!$operator_id){
            echo json_encode(array('status'=>false,'message'=>"Invalid Operator Request!"));exit;
        }

        if(!empty($request['session_id']) && !empty($request['user_id'])){
            
            $data = array("status"=>"disconnected","end_date_time" => date('Y-m-d H:i:s'));
            $this->_wpdb->update($this->dbSessionTable, $data, array('session_id'=> $request['session_id']));
            
            update_user_meta( $operator_id, 'golivestatus', 'offline');
            update_user_meta( $this->userId, 'tokboxtoken', '');
            
            // Update Customer Request Table
            $data = array("request_status"=>"completed");
            $this->_wpdb->update( $this->dbCustomerTable, $data, array( 'user_id'=> $request['user_id'], 'operator_id'=>$operator_id ));

            echo json_encode(array('status'=>true,'message'=>"Session Destroyed Successfully!"));
        }else{
            echo json_encode(array('status'=>false,'message'=>"Session Id not found !"));
            exit;
        }
        
    }

    public function getUserSessionFromDB($userId){
        $user_session_id = get_user_meta( $userId, 'tokboxsessionid',true );
        if($user_session_id){
            return $user_session_id;
        }
    }

    function vendorLogin($request){ 
        $creds = array();
        $creds['user_login'] = $request["username"];
        $creds['user_password'] =  $request["password"];
        $creds['remember'] = true;
        $user = wp_signon( $creds, false );
        if ( is_wp_error($user) ) {
            echo json_encode(array("code"=>'invalid_creds','message'=>'Incorrect username or Password.'));
            exit;
        } else {
            update_user_meta($user->ID, 'golive-app-login', 'yes');
        }
        $user->data->avtar = get_avatar_url( $user->data->ID );
        $user->data->notification_setting = get_user_meta($user->ID,'app-notification',true);
        $user->data->key = array('api_key'=>$this->apiKey,'secret_key'=>$this->apiSecret);
        return $user->data;
    }

    function savePushToken($request){

        $pushToken = $request['pushToken'];
        $playerId = $request['userId'];
        $deviceSerial = $request['deviceSerial'];
        
        if($request['wpUserID']){

            $wpUserID = $request['wpUserID'];


            $playerIds = get_user_meta($wpUserID, 'os_playerid', true);
            $deviceIds = get_user_meta($wpUserID, 'device_id', true);
            $pushtoken = get_user_meta($wpUserID, 'os_pushtoken', true);

            $pushNotificationData = array();
            $savePlayerIds = array();
            if(!is_array($playerIds)){
                if(!empty($playerIds)){
                    $pushNotificationData[] = array('deviceId'=>$deviceIds,'playerId'=>$playerIds,'pushtoken'=>$pushtoken);
                    $savePlayerIds[] = $playerIds;
                }
            }
            $pushNotificationData[] = array('deviceId'=>$deviceSerial,'playerId'=>$playerId,'pushtoken'=>$pushToken);
            $savePlayerIds[] = $playerId;

            update_user_meta($wpUserID, 'os_playerid', $savePlayerIds);
            update_user_meta($wpUserID, 'os_push_notification_data', $pushNotificationData);

            echo json_encode(array("status"=>'onsignal-saved','message'=>'Onesignal token data saved to wordpress.'));

        }else{

            echo json_encode(array("status"=>'user-missing','message'=>'Wordpress user not found.'));

        }
        exit;
    }

    /***
     * ToDo: For Vinay
     * Please use postman and send request to
     * https://www.theoddmarket.com/wp-json/go-live/send-message';
     * Method: POST
     * Data : user_id,vendor_id
     **/

    public function sendMessage($request){
        if(isset($request['vendor_id']))
            $request['seller_id'] = $request['vendor_id'];

        unset($request['vendor_id']);

        $operator_id = $this->get_face_2_face_admin($request);

        if(!$operator_id){
            echo json_encode(array('status'=>'error','message'=>"Invalid Operator Request!"));exit;
        }

        $userId = $request['user_id'];
        if(is_numeric($userId)):
            $user_info = get_userdata($userId);
            $member_phone_number=get_user_meta( $userId,'phone_number',true );
            $member_email=$user_info->user_email;
        else:
            $guest_info= str_replace('wp','',$userId);
            $f2f_guest_id =  str_replace('f2fn','',$guest_info);
            $user_data = $this->_wpdb->get_row("SELECT phone,email FROM $this->dbGuestTable WHERE id = {$f2f_guest_id} LIMIT 1");
            $member_phone_number=$user_data['phone'];
            $member_email=$user_data['email'];
        endif;
        $_POST['content'] = "Sorry we missed you earlier but we are available to Face2Face call now. Please visit theoddmarket.com and Click Face 2 Face.";
        $headers = array('Content-Type: text/html; charset=UTF-8');
        wp_mail( $member_email, 'Seller is online', $_POST['content'],$headers  );
        
        // //UM()->Messaging_API()->api()->create_conversation( $userId , $vendorId );
        //$senderid = Joy_Of_Text_Plugin()->settings->get_smsprovider_settings('jot-smssenderid');
        //$data = Joy_Of_Text_Plugin()->currentsmsprovider->send_smsmessage($member_phone_number, $_POST['content'],$senderid);
        echo json_encode(array("status"=>'message-sent','message'=>'User Has Been Informed by sms and site message.'));
        exit;
    }

    public function pushNotificationSetting($request){
        $vendorId = $request['vendor_id'];
        $value = $request['value'];
        update_user_meta( $vendorId, 'app-notification', $value);
        if($value){
            echo json_encode(array('message' => 'Push notification has been enabled !'));
        }else{
            echo json_encode(array('message'=>'Push notification has been disabled !'));
        }
        exit;
    }
}
new Face2FaceTokBox;
?>