<?php 

class Face2FaceFrontend {

	protected $adminDetail,$currentUserDetail,$options;

	public function __construct() {
       	$this->options = get_option( 'face_2_face_data' );
       	$this->_init();
    }

    public function _init(){
    	$this->_get_log_user_detail();
    	$this->_get_admin_detail();
    	add_action( 'wp_enqueue_scripts', array($this, 'enqueue_style') );
    	add_action( 'wp_enqueue_scripts', array($this, 'enqueue_scripts') );
    	add_shortcode( 'live_streaming', array($this,'_show_go_live') );
		add_action( 'wp_footer', array($this,'_show_go_live_pages'), 100 );
    }

    public function enqueue_style() {
    	wp_enqueue_style( "face-2-face-font-awesome", "//cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.2/css/all.min.css", array(), 0.01, 'all' ); 
		wp_enqueue_style( "face-2-face-public", plugin_dir_url( __FILE__ ) . 'assets/css/face-2-face-public.css', array(), 0.01, 'all' ); 
		wp_enqueue_style( 'face-2-face-openTokChat-style', plugin_dir_url( __FILE__ ) . 'assets/css/jQuery.openTokChat.css', array(), 'all');
    }

    public function enqueue_scripts() {
		wp_enqueue_script( 'face-2-face-opentok-js', 'https://static.opentok.com/v2/js/opentok.min.js', array(), '1.0.0', false );
		wp_enqueue_script( 'face-2-face-tok-chat-js',plugin_dir_url( __FILE__ ) . 'assets/js/jQuery.openTokChat.js', array( 'jquery' ), '0.01', true );
    	wp_register_script( 'face-2-face-public', plugin_dir_url( __FILE__ ) . 'assets/js/face-2-face-public.js', array( 'jquery' ), '0.01', true );
    	$localize_data = array('reciever'=>$this->adminDetail->data,'customer'=>$this->currentUserDetail->data ,'apiKey'=>$this->options['api_key'],'ajax_url'=>admin_url( 'admin-ajax.php' ),'f2fn' =>wp_create_nonce('f2f-nonce'));
		$localize_data = apply_filters('f2f_localize',$localize_data);
        wp_localize_script( 'face-2-face-public', 'face_2_face_data',$localize_data );
		wp_enqueue_script( 'face-2-face-public' );
    }

    public function _get_admin_detail(){
    	$admin_id = isset( $this->options['face_2_face_admin'] ) ? esc_attr( $this->options['face_2_face_admin']) : '';
    	if(!empty($admin_id)){
    		$this->adminDetail = get_user_by( 'ID', $admin_id );
			unset($this->adminDetail->user_pass);
			
    		$this->adminDetail->avtar = get_avatar_url( $admin_id );
    	} else {
    		$this->adminDetail = array();
    	}
    }

    public function _get_log_user_detail(){
    	if( is_user_logged_in()){
    		$this->currentUserDetail = wp_get_current_user();
    		$this->currentUserDetail->avtar = get_avatar_url($this->currentUserDetail->ID );
			unset($this->adminDetail->user_pass);
    	}
    	else{
    		$res = new \stdClass();
    		$data = new \stdClass();
    		$res->data = $data;
    		$res->data->display_name='Guest User';
    		$res->data->ID=0;
    		$res->data->avtar=plugin_dir_url( __FILE__ ) . 'assets/images/default.png';
    		$this->currentUserDetail = $res;
    	}
    }

    public function _show_go_live($args){
		
    	if(!empty($this->adminDetail)){
			ob_start();
			if( is_user_logged_in()){
				$filename = dirname( __FILE__ ) . '/templates/face-2-face.php';
			} else {
				$filename = dirname( __FILE__ ) . '/templates/face-2-face-guest.php';
			}
			include $filename;
	    	return ob_get_clean();
	    } else {
	    	return 'Admin Setting Pending.';
	    }
    }

	public function _show_go_live_pages()
	{
		$show_face2face = false;
		if(!is_page()){
			
			return false;
		}
		
		$include_to = isset( $this->options['face_2_face_include_pages'] ) ?  $this->options['face_2_face_include_pages'] : array();
		$include_to = array_map( 'esc_attr', $include_to );

		$show_all_pages = isset( $this->options['face_2_face_all_pages'] ) ? esc_attr( $this->options['face_2_face_all_pages']) : '';
		if(!empty($show_all_pages)){
			$exclude_from = isset( $this->options['face_2_face_exclude_pages'] ) ? $this->options['face_2_face_exclude_pages'] : array();
			$exclude_from = array_map( 'esc_attr', $exclude_from );
		}
		
		if(!empty($include_to) && in_array(get_the_ID(),$include_to)){
			$show_face2face = true;
		}
		if(!empty($show_all_pages)){
			$show_face2face = true;
			
			if(!empty($exclude_from) && in_array(get_the_ID(),$exclude_from)){
				$show_face2face = false;
			}
		}
		
		if($show_face2face && !has_shortcode( get_the_content(get_the_ID()), 'live_streaming') ){
			
			if(!empty($this->adminDetail)){
				
				ob_start();
				if( is_user_logged_in()){
					$filename = dirname( __FILE__ ) . '/templates/face-2-face.php';
				} else {
					$filename = dirname( __FILE__ ) . '/templates/face-2-face-guest.php';
				}
				include $filename;
				$output = ob_get_clean();
			} else {
				$output = 'Admin Setting Pending.';
			}
			echo $output;
		}
	}
}

new Face2FaceFrontend;